==> soliq_id-1.4.36.tar.gz: lib/src/utils/utils.dart <==
import 'dart:io';
import 'dart:math';

import 'package:assets_audio_player/assets_audio_player.dart';
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:device_info_plus/device_info_plus.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:google_mlkit_face_detection/google_mlkit_face_detection.dart';
import 'package:internet_connection_checker/internet_connection_checker.dart';
import 'package:intl/intl.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:vibration/vibration.dart';

import '../data/model/angle_model.dart';
import '../data/model/connection_state_model.dart';


class Utils {
  List<FacePosition> compareFacePosition(List<FacePosition> donePositions) {
    var result = AngleModel.fullPositions;
    for (var item in donePositions) {
      if (result.contains(item)) result.remove(item);
    }
    return result;
  }

  List<int> doneFacePositions(List<FacePosition> donePositions) {
    List<int> result = [0, 0, 0, 0, 0, 0, 0, 0];

    for (var item in donePositions) {
      switch (item) {
        case FacePosition.Top:
          result[0] = 1;
          break;
        case FacePosition.TopRight:
          result[1] = 1;
          break;
        case FacePosition.Right:
          result[2] = 1;
          break;
        case FacePosition.BottomRight:
          result[3] = 1;
          break;
        case FacePosition.Bottom:
          result[4] = 1;
          break;
        case FacePosition.BottomLeft:
          result[5] = 1;
          break;
        case FacePosition.Left:
          result[6] = 1;
          break;
        case FacePosition.TopLeft:
          result[7] = 1;
          break;
      }
    }
    return result;
  }

  double suggestAngle(FacePosition position) {
    switch (position) {
      case FacePosition.Top:
        return -pi / 4;
      case FacePosition.TopRight:
        return -pi / 8;
      case FacePosition.Right:
        return 0;
      case FacePosition.BottomRight:
        return pi / 8;
      case FacePosition.Bottom:
        return pi / 4;
      case FacePosition.BottomLeft:
        return 3 * pi / 8;
      case FacePosition.Left:
        return pi;
      case FacePosition.TopLeft:
        return -3 * pi / 8;
    }
  }

  String currencyFormatter(num? number, {decimalDigit = 2}) {
    final formatCurrency = NumberFormat.currency(
        locale: "en_US", symbol: "", decimalDigits: decimalDigit);
    return formatCurrency
        .format(numToDouble(number ?? 0.00))
        .replaceAll(",", " ");
  }

  double? numToDouble(num allSum) {
    double result = 0.00;

    try {
      int dat = 0;
      dat = (allSum.toDouble() + 0.00).toInt();
      result = double.parse("$dat.00");
    } catch (e) {
      debugPrint(e.toString());
    }

    try {
      result = allSum.toDouble();
    } catch (e) {
      debugPrint(e.toString());
    }
    return result;
  }

  List<PositionModel> randomTaskPosition(int count) {
    List<PositionModel> result = [];
    var list = allTaskPosition();
    list.removeLast();

    if (list.length > count) {
      for (int i = 0; i < count; i++) {
        var randomItem = (list..shuffle()).first;
        result.add(randomItem);
        list.remove(randomItem);
      }
      result.add(PositionModel(
          id: 7,
          variant: TaskVariantEnum.straight,
          image: "packages/soliq_id/lib/src/assets/lottie/positions/camera.json",
          title: 'up'));
    } else {
      throw "Xato qiymat kiritildi";
    }

    return result;
  }

  List<PositionModel> tasksFromTasks(List<int> tasksList) {
    List<PositionModel> result = [];

    for (int i = 0; i < tasksList.length; i++) {
      result.add(getPositionFromID(tasksList[i]));
    }

    return result;
  }

  static Future<void> checkInternet(
      {required BuildContext context,
      required Function() function,
      Function()? onNoTap}) async {
    var connectState = await internetConnectionState();
    var title = '';
    switch (connectState.connectionState) {
      case 0:
        title = "Internet yoq";
        break;
      case 1:
      case 3:
        return function();
      case 2:
      case 4:
        title = "Internet sekin";
        break;
      default:
        return;
    }

  }

  static Future<void> changeLanguage(BuildContext context, String language,
      {bool changeOnServer = false}) async {
    if (changeOnServer) {
      Map<String, dynamic> body = {"lang": language};
    }
  }

  static Future<ConnectionStateModel> internetConnectionState() async {
    var connectionState = ConnectionStateModel();
    var connectivityResult = await (Connectivity().checkConnectivity());

    switch (connectivityResult) {
      case ConnectivityResult.mobile:
        connectionState.source = 'mobile';
        if (await InternetConnectionChecker().hasConnection) {
          connectionState.connectionState = 1;
          connectionState.isConnected = true;
        } else {
          connectionState.connectionState = 2;
          connectionState.isConnected = false;
        }
        break;
      case ConnectivityResult.wifi:
        connectionState.source = 'wifi';
        if (await InternetConnectionChecker().hasConnection) {
          connectionState.connectionState = 3;
          connectionState.isConnected = true;
        } else {
          connectionState.connectionState = 4;
          connectionState.isConnected = false;
        }
        break;

      default:
        connectionState.connectionState = 0;
        connectionState.isConnected = false;
        break;
    }

    debugPrint(
        "source - ${connectionState.source}\nconnectionState - ${connectionState.connectionState}\nconnected - ${connectionState.isConnected}");
    return connectionState;
  }

  List<PositionModel> allTaskPosition() {
    var directory = "packages/soliq_id/lib/src/assets/lottie/positions";
    return [
      PositionModel(
          id: 1,
          variant: TaskVariantEnum.top,
          image: "$directory/up.json",
          title: "up"),
      PositionModel(
          id: 2,
          variant: TaskVariantEnum.right,
          image: "$directory/right.json",
          title: "right"),
      PositionModel(
          id: 3,
          variant: TaskVariantEnum.down,
          image: "$directory/down.json",
          title: "down"),
      PositionModel(
          id: 4,
          variant: TaskVariantEnum.left,
          image: "$directory/left.json",
          title: "left"),
      PositionModel(
          id: 5,
          variant: TaskVariantEnum.smile,
          image: "$directory/smile.json",
          title: "smile"),
      PositionModel(
          id: 6,
          variant: TaskVariantEnum.blink,
          image: "$directory/blink.json",
          title: "blink"),
      PositionModel(
          id: 7,
          variant: TaskVariantEnum.straight,
          image: "$directory/camera.json",
          title: "straight"),
    ];
  }

  Future<void> voiceAndVibrate({VoiceType? type = VoiceType.success}) async {
    if (type != VoiceType.none) {
      final player = AssetsAudioPlayer.newPlayer().open(
        Audio("assets/audio/${type!.name}.mp3"),
        autoStart: true,
        showNotification: true,
      );
      player.ignore();
    }
    Vibration.vibrate(amplitude: type == VoiceType.none ? 15 : 64);
  }

 static Future<Map<String, dynamic>> getDeviceDetails() async {
    String deviceName = '';
    String identifier = '';
    String brand = '';
    String appVersion = '';
    final DeviceInfoPlugin deviceInfoPlugin = DeviceInfoPlugin();
    try {
      if (Platform.isAndroid) {
        var build = await deviceInfoPlugin.androidInfo;
        deviceName = build.model ;
        identifier = build.device ;
        brand = build.brand ;
        appVersion =
            "Android ${build.version.release }, API ${build.version.sdkInt ?? 0}";
      } else if (Platform.isIOS) {
        var data = await deviceInfoPlugin.iosInfo;
        deviceName = data.name ;
        identifier = data.identifierForVendor ?? "";
        brand = data.utsname.nodename ; // todo check
        appVersion =
            "iOS ${data.utsname.release}, ${data.utsname.machine}, Version ${data.utsname.version }";
      } else if (Platform.isMacOS) {
        var data = await deviceInfoPlugin.macOsInfo;
        deviceName = data.computerName;
        identifier = data.systemGUID ?? ""; //UUID for iOS
        brand = data.computerName; // todo check
        appVersion =
            "MacOs ${data.osRelease}, Version ${data.kernelVersion}"; //todo check
      }
    } on PlatformException {
      if (kDebugMode) {
        print('Failed to get platform version');
      }
    }

    var map = {
      "deviceId": identifier,
      "deviceName": brand.toUpperCase(),
      "factoryName": deviceName,
      "osType": osType(),
      "osVersion": appVersion,
      "package": 'uz.soliq.mobile',
      "appVersion": (await initVersion()),
      "lang": "uz", //todo tilni berish kerak
    };

    return map;
  }

  static Future<String> getDeviceId() async {
    String identifier = '';
    final DeviceInfoPlugin deviceInfoPlugin = DeviceInfoPlugin();
    try {
      if (Platform.isAndroid) {
        var build = await deviceInfoPlugin.androidInfo;
        identifier = build.device ?? ""; //UUID for Android
      } else if (Platform.isIOS) {
        var data = await deviceInfoPlugin.iosInfo;
        identifier = data.identifierForVendor ?? ""; //UUID for iOS
      } else if (Platform.isMacOS) {
        var data = await deviceInfoPlugin.macOsInfo;
        identifier = data.systemGUID ?? ""; //UUID for iOS
      }
    } on PlatformException {
      if (kDebugMode) {
        print('Failed to get platform version');
      }
    }
    return identifier;
  }

  static int osType() {
    var result = 0;
    if (Platform.isAndroid) result = 1;
    if (Platform.isIOS) result = 2;
    return result;
  }

  static Future<String> initVersion() async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    return packageInfo.version;
  }

  static void onError(BuildContext context, onError) {
    debugPrint("onError: $onError");
  }

  int getTaskIdFromVariant(TaskVariantEnum variant) {
    var tasks = Utils().allTaskPosition();
    for (int i = 0; i < tasks.length; i++) {
      if (tasks[i].variant == variant) {
        return tasks[i].id;
      }
    }
    return 0;
  }

  PositionModel getPositionFromID(int id) {
    var tasks = Utils().allTaskPosition();
    for (int i = 0; i < tasks.length; i++) {
      if (tasks[i].id == id) {
        return tasks[i];
      }
    }
    return tasks.last;
  }

  int brightness(InputImage image) {
    var data = image.bytes!;
    var colorSum = 0;
    for (var x = 0; x < data.length; x += 4) {
      int r = data[x];
      int g = data[x + 1];
      int b = data[x + 2];
      int avg = ((r + g + b) / 3).floor();
      colorSum += avg;
    }
    var brightness = colorSum
        .floor();
    return brightness;
  }
}


double calcScale({
  required double srcWidth,
  required double srcHeight,
  required double minWidth,
  required double minHeight,
}) {
  var scaleW = srcWidth / minWidth;
  var scaleH = srcHeight / minHeight;
  var scale = max(1.0, min(scaleW, scaleH));
  return scale;
}

==> soliq_id-1.4.37.tar.gz: lib/src/utils/utils.dart <==
import 'dart:io';
import 'dart:math';

import 'package:device_info_plus/device_info_plus.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:google_mlkit_face_detection/google_mlkit_face_detection.dart';
import 'package:intl/intl.dart';
import 'package:just_audio/just_audio.dart';
import 'package:package_info_plus/package_info_plus.dart';
import 'package:soliq_id/src/data/model/response/device_model.dart';
import 'package:vibration/vibration.dart';

import '../data/model/angle_model.dart';

class Utils {
  List<FacePosition> compareFacePosition(List<FacePosition> donePositions) {
    var result = AngleModel.fullPositions;
    for (var item in donePositions) {
      if (result.contains(item)) result.remove(item);
    }
    return result;
  }

  List<int> doneFacePositions(List<FacePosition> donePositions) {
    List<int> result = [0, 0, 0, 0, 0, 0, 0, 0];

    for (var item in donePositions) {
      switch (item) {
        case FacePosition.Top:
          result[0] = 1;
          break;
        case FacePosition.TopRight:
          result[1] = 1;
          break;
        case FacePosition.Right:
          result[2] = 1;
          break;
        case FacePosition.BottomRight:
          result[3] = 1;
          break;
        case FacePosition.Bottom:
          result[4] = 1;
          break;
        case FacePosition.BottomLeft:
          result[5] = 1;
          break;
        case FacePosition.Left:
          result[6] = 1;
          break;
        case FacePosition.TopLeft:
          result[7] = 1;
          break;
      }
    }
    return result;
  }

  double suggestAngle(FacePosition position) {
    switch (position) {
      case FacePosition.Top:
        return -pi / 4;
      case FacePosition.TopRight:
        return -pi / 8;
      case FacePosition.Right:
        return 0;
      case FacePosition.BottomRight:
        return pi / 8;
      case FacePosition.Bottom:
        return pi / 4;
      case FacePosition.BottomLeft:
        return 3 * pi / 8;
      case FacePosition.Left:
        return pi;
      case FacePosition.TopLeft:
        return -3 * pi / 8;
    }
  }

  String currencyFormatter(num? number, {decimalDigit = 2}) {
    final formatCurrency = NumberFormat.currency(
        locale: "en_US", symbol: "", decimalDigits: decimalDigit);
    return formatCurrency
        .format(numToDouble(number ?? 0.00))
        .replaceAll(",", " ");
  }

  double? numToDouble(num allSum) {
    double result = 0.00;

    try {
      int dat = 0;
      dat = (allSum.toDouble() + 0.00).toInt();
      result = double.parse("$dat.00");
    } catch (e) {
      debugPrint(e.toString());
    }

    try {
      result = allSum.toDouble();
    } catch (e) {
      debugPrint(e.toString());
    }
    return result;
  }

  List<PositionModel> randomTaskPosition(int count) {
    List<PositionModel> result = [];
    var list = allTaskPosition();
    list.removeLast();

    if (list.length > count) {
      for (int i = 0; i < count; i++) {
        var randomItem = (list..shuffle()).first;
        result.add(randomItem);
        list.remove(randomItem);
      }
      result.add(PositionModel(
          id: 7,
          variant: TaskVariantEnum.straight,
          image: "assets/lottie/positions/camera.json",
          title: 'up'));
    } else {
      throw "Xato qiymat kiritildi";
    }

    return result;
  }

  List<PositionModel> tasksFromTasks(List<int> tasksList) {
    List<PositionModel> result = [];

    for (int i = 0; i < tasksList.length; i++) {
      result.add(getPositionFromID(tasksList[i]));
    }

    return result;
  }

  // static Future<void> checkInternet(
  //     {required BuildContext context,
  //     required Function() function,
  //     Function()? onNoTap}) async {
  //   var connectState = await internetConnectionState();
  //   var title = '';
  //   switch (connectState.connectionState) {
  //     case 0:
  //       title = "Internet yoq";
  //       break;
  //     case 1:
  //     case 3:
  //       return function();
  //     case 2:
  //     case 4:
  //       title = "Internet sekin";
  //       break;
  //     default:
  //       return;
  //   }
  // }

  static Future<void> changeLanguage(BuildContext context, String language,
      {bool changeOnServer = false}) async {
    if (changeOnServer) {
      Map<String, dynamic> body = {"lang": language};
    }
  }

  // static Future<ConnectionStateModel> internetConnectionState() async {
  //   var connectionState = ConnectionStateModel();
  //   var connectivityResult = await (Connectivity().checkConnectivity());
  //
  //   switch (connectivityResult) {
  //     case ConnectivityResult.mobile:
  //       connectionState.source = 'mobile';
  //       if (await InternetConnectionChecker().hasConnection) {
  //         connectionState.connectionState = 1;
  //         connectionState.isConnected = true;
  //       } else {
  //         connectionState.connectionState = 2;
  //         connectionState.isConnected = false;
  //       }
  //       break;
  //     case ConnectivityResult.wifi:
  //       connectionState.source = 'wifi';
  //       if (await InternetConnectionChecker().hasConnection) {
  //         connectionState.connectionState = 3;
  //         connectionState.isConnected = true;
  //       } else {
  //         connectionState.connectionState = 4;
  //         connectionState.isConnected = false;
  //       }
  //       break;
  //
  //     default:
  //       connectionState.connectionState = 0;
  //       connectionState.isConnected = false;
  //       break;
  //   }
  //
  //   debugPrint(
  //       "source - ${connectionState.source}\nconnectionState - ${connectionState.connectionState}\nconnected - ${connectionState.isConnected}");
  //   return connectionState;
  // }

  List<PositionModel> allTaskPosition() {
    var directory = "assets/lottie/positions";
    return [
      PositionModel(
          id: 1,
          variant: TaskVariantEnum.top,
          image: "$directory/up.json",
          title: "up"),
      PositionModel(
          id: 2,
          variant: TaskVariantEnum.right,
          image: "$directory/right.json",
          title: "right"),
      PositionModel(
          id: 3,
          variant: TaskVariantEnum.down,
          image: "$directory/down.json",
          title: "down"),
      PositionModel(
          id: 4,
          variant: TaskVariantEnum.left,
          image: "$directory/left.json",
          title: "left"),
      PositionModel(
          id: 5,
          variant: TaskVariantEnum.smile,
          image: "$directory/smile.json",
          title: "smile"),
      PositionModel(
          id: 6,
          variant: TaskVariantEnum.blink,
          image: "$directory/blink.json",
          title: "blink"),
      PositionModel(
          id: 7,
          variant: TaskVariantEnum.straight,
          image: "$directory/camera.json",
          title: "straight"),
    ];
  }

  Future<void> voiceAndVibrate({VoiceType? type = VoiceType.success}) async {
    if (type != VoiceType.none) {
      final player = AudioPlayer();
      await  player.setAsset("assets/audio/${type!.name}.mp3", );
      await player.play();
      player.stop();
    }
    Vibration.vibrate(amplitude: type == VoiceType.none ? 15 : 64);
  }

  static Future<DeviceModel> getDeviceDetails() async {
    String deviceName = '';
    String brand = '';
    String appVersion = '';
    final DeviceInfoPlugin deviceInfoPlugin = DeviceInfoPlugin();
    try {
      if (Platform.isAndroid) {
        var build = await deviceInfoPlugin.androidInfo;
        deviceName = build.model;
        brand = build.brand;
        appVersion =
            "Android ${build.version.release}, API ${build.version.sdkInt}";
      } else if (Platform.isIOS) {
        var data = await deviceInfoPlugin.iosInfo;
        deviceName = data.name;
        brand = data.utsname.nodename;
        appVersion =
            "iOS ${data.utsname.release}, ${data.utsname.machine}, Version ${data.utsname.version}";
      } else if (Platform.isMacOS) {
        var data = await deviceInfoPlugin.macOsInfo;
        deviceName = data.computerName;
        brand = data.computerName;
        appVersion = "MacOs ${data.osRelease}, Version ${data.kernelVersion}";
      }
    } on PlatformException {
      if (kDebugMode) {
        print('Failed to get platform version');
      }
    }

    final deviceId = await Utils.getDeviceId();
    return DeviceModel(
      projectId: 0,
      firebaseId: "",
      deviceId: deviceId,
      deviceName: deviceName,
      factoryName: brand.toUpperCase(),
      osVersion: appVersion,
      appVersion: (await initVersion()),
      osType: osType(),
      lang: "uz",
    );
  }

  static Future<String> getDeviceId() async {
    String identifier = '';
    final DeviceInfoPlugin deviceInfoPlugin = DeviceInfoPlugin();
    try {
      if (Platform.isAndroid) {
        var build = await deviceInfoPlugin.androidInfo;
        identifier = build.device;
      } else if (Platform.isIOS) {
        var data = await deviceInfoPlugin.iosInfo;
        identifier = data.identifierForVendor ?? "";
      } else if (Platform.isMacOS) {
        var data = await deviceInfoPlugin.macOsInfo;
        identifier = data.systemGUID ?? "";
      }
    } on PlatformException {
      if (kDebugMode) {
        print('Failed to get platform version');
      }
    }
    return identifier;
  }

  static int osType() {
    var result = 0;
    if (Platform.isAndroid) result = 1;
    if (Platform.isIOS) result = 2;
    return result;
  }

  static Future<String> initVersion() async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    return packageInfo.version;
  }

  static void onError(BuildContext context, onError) {
    debugPrint("onError: $onError");
  }

  int getTaskIdFromVariant(TaskVariantEnum variant) {
    var tasks = Utils().allTaskPosition();
    for (int i = 0; i < tasks.length; i++) {
      if (tasks[i].variant == variant) {
        return tasks[i].id;
      }
    }
    return 0;
  }

  PositionModel getPositionFromID(int id) {
    var tasks = Utils().allTaskPosition();
    for (int i = 0; i < tasks.length; i++) {
      if (tasks[i].id == id) {
        return tasks[i];
      }
    }
    return tasks.last;
  }

  int brightness(InputImage image) {
    var data = image.bytes!;
    var colorSum = 0;
    for (var x = 0; x < data.length; x += 4) {
      int r = data[x];
      int g = data[x + 1];
      int b = data[x + 2];
      int avg = ((r + g + b) / 3).floor();
      colorSum += avg;
    }
    var brightness = colorSum.floor();
    return brightness;
  }


}

double calcScale({
  required double srcWidth,
  required double srcHeight,
  required double minWidth,
  required double minHeight,
}) {
  var scaleW = srcWidth / minWidth;
  var scaleH = srcHeight / minHeight;
  var scale = max(1.0, min(scaleW, scaleH));
  return scale;
}
